@@ -941,6 +941,30 @@ class DocumentHighlightRegistrationOptions(TextDocumentRegistrationOptions, Docu
     pass
 
 
+@dataclass(repr=False)
+class LinkedEditingRangeOptions(WorkDoneProgressOptions):
+    pass
+
+
+@dataclass(repr=False)
+class LinkedEditingRangeRegistrationOptions(
+    TextDocumentRegistrationOptions, LinkedEditingRangeOptions, StaticRegistrationOptions
+):
+    pass
+
+
+@dataclass(repr=False)
+class SelectionRangeOptions(WorkDoneProgressOptions):
+    pass
+
+
+@dataclass(repr=False)
+class SelectionRangeRegistrationOptions(
+    TextDocumentRegistrationOptions, SelectionRangeOptions, StaticRegistrationOptions
+):
+    pass
+
+
 @dataclass(repr=False)
 class ServerCapabilities(Model):
     text_document_sync: Union[TextDocumentSyncOptions, TextDocumentSyncKind, None] = None
@@ -963,10 +987,10 @@ class ServerCapabilities(Model):
     # TODO rename_provider: Union[bool, RenameOptions, None] = None
     folding_range_provider: Union[bool, FoldingRangeOptions, FoldingRangeRegistrationOptions, None] = None
     execute_command_provider: Optional[ExecuteCommandOptions] = None
-    # TODO selection_range_provider: Union[bool, SelectionRangeOptions, SelectionRangeRegistrationOptions, None] = None
-    # TODO linked_editing_range_provider: Union[
-    #     boolean, LinkedEditingRangeOptions, LinkedEditingRangeRegistrationOptions, None
-    # ] = None
+    selection_range_provider: Union[bool, SelectionRangeOptions, SelectionRangeRegistrationOptions, None] = None
+    linked_editing_range_provider: Union[
+        bool, LinkedEditingRangeOptions, LinkedEditingRangeRegistrationOptions, None
+    ] = None
     # TODO call_hierarchy_provider: Union[boolean, CallHierarchyOptions, CallHierarchyRegistrationOptions, None] = None
     semantic_tokens_provider: Union[SemanticTokensOptions, SemanticTokensRegistrationOptions, None] = None
     # TODO moniker_provider: Union[bool, MonikerOptions, MonikerRegistrationOptions, None] = None
@@ -1877,3 +1901,31 @@ class DocumentHighlightKind(Enum):
 class DocumentHighlight(Model):
     range: Range
     kind: Optional[DocumentHighlightKind] = None
+
+
+@dataclass(repr=False)
+class LinkedEditingRangeParams(WorkDoneProgressParams, TextDocumentPositionParams):
+    pass
+
+
+@dataclass(repr=False)
+class LinkedEditingRanges(Model):
+    ranges: List[Range]
+    word_pattern: Optional[str] = None
+
+
+@dataclass(repr=False)
+class _SelectionRangeParams(Model):
+    text_document: TextDocumentIdentifier
+    positions: List[Position]
+
+
+@dataclass(repr=False)
+class SelectionRangeParams(WorkDoneProgressParams, PartialResultParams, _SelectionRangeParams):
+    pass
+
+
+@dataclass(repr=False)
+class SelectionRange(Model):
+    range: Range
+    parent: Optional[SelectionRange] = None
